healthcheck

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package healthcheck checks for missing binaries that the user needs to install.

Index

Constants

This section is empty.

Variables

var DependencyCheckers = []DependencyChecker{
	system{},
	builds{},
	snapcraft.Pipe{},
	sign.Pipe{},
	sign.BinaryPipe{},
	sign.DockerPipe{},
	sbom.Pipe{},
	docker.Pipe{},
	docker.ManifestPipe{},
	dockerv2.Base{},
	chocolatey.Pipe{},
	nix.New(),
	flatpak.Pipe{},
}

DependencyCheckers is the list of dependency checkers.

var HealthCheckers = []HealthChecker{
	dockerv2.Base{},
	docker.Pipe{},
}

HealthCheckers is the list of health checkers.

Functions

This section is empty.

Types

type DependencyChecker

type DependencyChecker interface {
	fmt.Stringer

	// Dependencies return the binaries of the dependencies needed.
	Dependencies(ctx *context.Context) []string
}

DependencyChecker should be implemented by pipes that want checks.

type HealthChecker

type HealthChecker interface {
	fmt.Stringer

	// Healthcheck does checks that are more complex than [DependencyChecker],
	// and returns an error if they fail.
	Healthcheck(ctx *context.Context) error
}

HealthChecker should be implemented by pipes that want checks.

Jump to